==> nui_form-0.0.14.tar.gz: lib/component/nuif_list.dart <==
import 'dart:developer';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_form/nuif_form.dart';
import 'package:nui_form/nuif_form_component.dart';
import 'package:nui_core/code/nui_code_util.dart';

class NUIFList extends NUIFormContainer{
  NUIFList({
    @required List<NUIFormComponent> items,
    @required String inpId,
    this.divider:0.0,
    this.padding,
    double width,
    double height,
    Alignment align,
    EdgeInsets margin,
    double weight}): super(items: items, inpId : inpId, inpType: ComponentType.LIST, width: width, height: height, weight: weight, margin: margin, align: align);
  double divider;
  EdgeInsets padding;

  @override
  Widget toWidget({AllButtonClickListener allButtonClickListener, AllTextChangeListener allTextChangeListener, AllItemSelectListener allItemSelectListener, Key key}) {
    return NUIFListLayout(item: this, key: key, allTextChangeListener: allTextChangeListener, allButtonClickListener: allButtonClickListener, allItemSelectListener: allItemSelectListener,);
  }
}

class NUIFListLayout extends StatefulWidget {
  NUIFListLayout({@required this.item, this.allTextChangeListener, this.allButtonClickListener, this.allItemSelectListener, Key key}): super(key: key);
  final NUIFList item;
  final AllTextChangeListener allTextChangeListener;
  final AllButtonClickListener allButtonClickListener;
  final AllItemSelectListener allItemSelectListener;
  @override
  _NUIFListLayoutState createState() => _NUIFListLayoutState();
}

class _NUIFListLayoutState extends NUIFState<NUIFListLayout, NUIFList> {

  @override
  void initState(){
    this.item = widget.item;
    super.initState();
  }

  Widget _renderComponent(NUIFormComponent comp){
    return Container(
      child: comp.toWidget(allTextChangeListener: widget.allTextChangeListener, allButtonClickListener: widget.allButtonClickListener, allItemSelectListener: widget.allItemSelectListener, key: widget.key),
      width: comp.width,
      height: comp.height,
    );
  }

  List<Widget> _renderAllComponents(List<NUIFormComponent> items, double divider){
    List<Widget> views = List();
    bool addDivider = divider != null && divider > 0;
    NUICodeUtil.loop(items, (data, position, isFirst, isLast) {
      if(position != 0 && addDivider){
        views.add(Divider(height: item.divider ?? 0, thickness: 0, color: Colors.transparent,));
      }
      views.add(_renderComponent(data));
    });
    return views;
  }

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: ListView(
        key: widget.key,
        children: _renderAllComponents(item.items, item.divider),
      ),
    );
  }
}

==> nui_form-0.0.26.tar.gz: lib/component/nuif_list.dart <==
import 'dart:developer';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_form/nuif_form.dart';
import 'package:nui_form/nuif_form_component.dart';
import 'package:nui_core/code/nui_code_util.dart';

class NUIFList extends NUIFormContainer{
  NUIFList({
    @required List<NUIFormComponent> items,
    @required String inpId,
    this.divider:0.0,
    this.padding,
    double width,
    double height,
    Alignment align,
    EdgeInsets margin,
    double weight}): super(items: items, inpId : inpId, inpType: ComponentType.LIST, width: width, height: height, weight: weight, margin: margin, align: align);
  double divider;
  EdgeInsets padding;

  @override
  Widget toWidget({AllButtonClickListener allButtonClickListener, AllTextChangeListener allTextChangeListener, AllItemSelectListener allItemSelectListener, Key key}) {
    return NUIFListLayout(item: this, key: key, allTextChangeListener: allTextChangeListener, allButtonClickListener: allButtonClickListener, allItemSelectListener: allItemSelectListener,);
  }
}

class NUIFListLayout extends StatefulWidget {
  NUIFListLayout({@required this.item, this.allTextChangeListener, this.allButtonClickListener, this.allItemSelectListener, Key key}): super(key: key);
  final NUIFList item;
  final AllTextChangeListener allTextChangeListener;
  final AllButtonClickListener allButtonClickListener;
  final AllItemSelectListener allItemSelectListener;
  @override
  _NUIFListLayoutState createState() => _NUIFListLayoutState();
}

class _NUIFListLayoutState extends NUIFState<NUIFListLayout, NUIFList> {

  @override
  void initState(){
    this.item = widget.item;
    super.initState();
  }

  Widget _renderComponent(NUIFormComponent comp){
    return Container(
      child: comp.toWidget(allTextChangeListener: widget.allTextChangeListener, allButtonClickListener: widget.allButtonClickListener, allItemSelectListener: widget.allItemSelectListener, key: widget.key),
      width: comp.width,
      height: comp.height,
    );
  }

  List<Widget> _renderAllComponents(List<NUIFormComponent> items, double divider){
    List<Widget> views = List();
    bool addDivider = divider != null && divider > 0;
    NUICodeUtil.loop<NUIFormComponent>(items, (data, position, isFirst, isLast) {
      if(position != 0 && addDivider){
        views.add(Divider(height: item.divider ?? 0, thickness: 0, color: Colors.transparent,));
      }
      if(data.show != false) {
        views.add(_renderComponent(data));
      }
    });
    return views;
  }

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: ListView(
        key: widget.key,
        children: _renderAllComponents(item.items, item.divider),
      ),
    );
  }
}
